Contribute
==========

You want to hack new features into km3pipe or are just here to fix a
bug? Great! Let's get you started.

If you have any questions, join us in the `#km3pipe`_ Slack channel.

.. _#km3pipe: https://km3net.slack.com/messages/km3pipe

.. toctree::
  dev
  doc
